resume v0.0.6 Resume.Router.Helpers

Module with named helpers generated from Resume.Router.

Summary

Functions

change_password_path(conn_or_endpoint, action, email, token)
change_password_path(conn_or_endpoint, action, email, token, params)
change_password_url(conn_or_endpoint, action, email, token)
change_password_url(conn_or_endpoint, action, email, token, params)
forgot_password_path(conn_or_endpoint, action)
forgot_password_path(conn_or_endpoint, action, params)
forgot_password_url(conn_or_endpoint, action)
forgot_password_url(conn_or_endpoint, action, params)
login_path(conn_or_endpoint, action)
login_path(conn_or_endpoint, action, params)
login_url(conn_or_endpoint, action)
login_url(conn_or_endpoint, action, params)
page_path(conn_or_endpoint, action)
page_path(conn_or_endpoint, action, params)
page_path(conn_or_endpoint, action, path, params)
page_url(conn_or_endpoint, action)
page_url(conn_or_endpoint, action, params)
page_url(conn_or_endpoint, action, path, params)
path(data, path)

Generates the path information including any necessary prefix.

static_path(conn, path)

Generates path to a static asset given its file path.

static_url(conn, path)

Generates url to a static asset given its file path.

url(data)

Generates the connection/endpoint base URL without any path information.